==> molecule-1.19.1.tar.gz: molecule-1.19.1/test/unit/command/test_list.py <==
#  Copyright (c) 2015-2016 Cisco Systems, Inc.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to
#  deal in the Software without restriction, including without limitation the
#  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
#  sell copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.

from molecule.command import list as command_list


def test_execute(capsys, molecule_instance):
    l = command_list.List({}, {}, molecule_instance)
    result = l.execute()

    out, _ = capsys.readouterr()

    assert 'ubuntu   (default)' in out
    assert 'centos7' in out
    assert (None, None) == result


def test_execute_with_porcelain(capsys, molecule_instance):
    command_args = {'porcelain': True}

    l = command_list.List({}, command_args, molecule_instance)
    result = l.execute()

    out, _ = capsys.readouterr()

    assert 'ubuntu   d' in out
    assert 'centos7' in out
    assert (None, None) == result

==> molecule-2.10.1.tar.gz: molecule-2.10.1/test/unit/command/test_list.py <==
#  Copyright (c) 2015-2017 Cisco Systems, Inc.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to
#  deal in the Software without restriction, including without limitation the
#  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
#  sell copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.

from molecule.command import list
from molecule.driver import base


def test_execute(capsys, config_instance):
    l = list.List(config_instance)
    x = [
        base.Status(
            instance_name='instance-1',
            driver_name='Docker',
            provisioner_name='Ansible',
            scenario_name='default',
            created='False',
            converged='False'),
        base.Status(
            instance_name='instance-2',
            driver_name='Docker',
            provisioner_name='Ansible',
            scenario_name='default',
            created='False',
            converged='False'),
    ]
    assert x == l.execute()
